"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var rxjs_1 = require("rxjs");
var operators_1 = require("rxjs/operators");
var genericRetryStrategy = function (_a) {
    var _b = _a === void 0 ? {} : _a, _c = _b.delay, delay = _c === void 0 ? 1000 : _c, _d = _b.maxRetryAttempts, maxRetryAttempts = _d === void 0 ? 3 : _d, _e = _b.scalingFactor, scalingFactor = _e === void 0 ? 1 : _e, _f = _b.excludedStatusCodes, excludedStatusCodes = _f === void 0 ? [] : _f;
    return function (attempts) {
        return attempts.pipe(operators_1.mergeMap(function (error, i) {
            var retryAttempt = i + 1;
            // if maximum number of retries have been met
            // or response is a status code we don't wish to retry, throw error
            if (retryAttempt > maxRetryAttempts || excludedStatusCodes.find(function (e) { return e === error.status; })) {
                return rxjs_1.throwError(error);
            }
            var tryAfter = delay * Math.pow(scalingFactor, (retryAttempt - 1));
            console.log("Attempt " + retryAttempt + ": retrying in " + tryAfter + "ms");
            // retry after 1s, 2s, etc...
            return rxjs_1.timer(tryAfter);
        }), operators_1.finalize(function () { return console.log('Done with retrying.'); }));
    };
};
exports.retryWithDelay = function (config) {
    if (config === void 0) { config = {}; }
    return function (source) {
        return source.pipe(operators_1.retryWhen(genericRetryStrategy(config)));
    };
};
//# sourceMappingURL=retry-delay.operator.js.map